@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xine.h.in,v 1.146 2005/10/30 02:18:35 miguelfreitas Exp $
+ * $Id: xine.h.in,v 1.149 2006/06/22 10:38:37 klan Exp $
  *
  * public xine-lib (libxine) interface and documentation
  *
@@ -111,8 +111,8 @@ int  xine_check_version (int major, int minor, int sub) ;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 1
-#define XINE_SUB_VERSION   1
-#define XINE_VERSION       "1.1.1"
+#define XINE_SUB_VERSION   2
+#define XINE_VERSION       "1.1.2"
 
 /*
  * pre-init the xine engine
@@ -367,6 +367,8 @@ int  xine_get_param (xine_stream_t *stream, int param);
 #define XINE_PARAM_VO_ZOOM_Y               0x0100000d /* percent            */
 #define XINE_PARAM_VO_PAN_SCAN             0x01000009 /* bool               */
 #define XINE_PARAM_VO_TVMODE               0x0100000a /* ???                */
+#define XINE_PARAM_VO_WINDOW_WIDTH         0x0100000f /* readonly           */
+#define XINE_PARAM_VO_WINDOW_HEIGHT        0x01000010 /* readonly           */
 #define XINE_PARAM_VO_CROP_LEFT            0x01000020 /* crop frame pixels  */
 #define XINE_PARAM_VO_CROP_RIGHT           0x01000021 /* crop frame pixels  */
 #define XINE_PARAM_VO_CROP_TOP             0x01000022 /* crop frame pixels  */
@@ -1522,9 +1524,16 @@ void xine_config_reset (xine_t *self);
 #define XINE_EVENT_VDR_VOLMINUS         330
 #define XINE_EVENT_VDR_MUTE             331
 #define XINE_EVENT_VDR_AUDIO            332
+#define XINE_EVENT_VDR_INFO             333
 /* some space for further keys */
 #define XINE_EVENT_VDR_SETVIDEOWINDOW   350
 #define XINE_EVENT_VDR_FRAMESIZECHANGED 351
+#define XINE_EVENT_VDR_SELECTAUDIO      352
+#define XINE_EVENT_VDR_TRICKSPEEDMODE   353
+#define XINE_EVENT_VDR_PLUGINSTARTED    354
+
+/* events generated from post plugins */
+#define XINE_EVENT_POST_TVTIME_FILMMODE_CHANGE   400
 
 /*
  * xine event struct
